@@ -8,6 +8,10 @@
 #include <sys/param.h>
 #endif
 
+#ifdef Q_OS_HAIKU
+#define S_BLKSIZE 512
+#endif
+
 static void outputError(const QByteArray &path)
 {
     /// show error message that stat or opendir may give
@@ -108,7 +112,7 @@ void POSIXWalker::next()
         if (links > 1 && !m_entry.isSkippable) {
             ino_t inode = statbuf.st_ino;
             // If we already counted this inode, skip it
-            if (m_countedHardlinks.find(inode) != m_countedHardlinks.end()) {
+            if (m_countedHardlinks.contains(inode)) {
                 m_entry.isDuplicate = true;
             } else {
                 // Only add to counted hard links if we are going to count it
